
# Slot: has exposure parts




URI: [biolink:has_exposure_parts](https://w3id.org/biolink/vocab/has_exposure_parts)

## Domain and Range

[Treatment](Treatment.md) ->  <sub>1..*</sub> [DrugExposure](DrugExposure.md)

## Parents


## Children


## Used by

 * [Treatment](Treatment.md)
